<template>
    <div class="home-container">
        <div style="height: 100%">
            <el-row class="homeCard">
                <div class="basic-line">
                    <span>实验名称：</span>
                    <el-input v-model="developState.searchQuery.experimentName" clearable filterable class="input-box" placeholder="实验名称">
                    </el-input>
                </div>
<!--                <div class="basic-line">-->
<!--                    <span>实验类型：</span>-->
<!--                    <el-select v-model="developState.searchQuery.experimentType" clearable filterable class="input-box" placeholder="实验类型">-->
<!--                        <el-option v-for="item in developState.experimentTypeList" :key="item.id" :label="item.name" :value="item.id"></el-option>-->
<!--                    </el-select>-->
<!--                </div>-->
                <div style="padding-bottom: 10px">
                    <el-button type="primary" @click="getReportData">查询</el-button>
                    <el-button plain @click="reset">重置</el-button>
                </div>
            </el-row>
            <div class="homeCard">
                <div class="main-card">
                    <el-row class="cardTop">
                    </el-row>
                    <el-table ref="multipleTableRef" :data="developState.developData" style="width: 100%" height="calc(100% - 100px)" :header-cell-style="{ background: '#fafafa' }">
                        <el-table-column prop="experimentCode" label="实验编号"/>
                        <el-table-column prop="experimentName" label="实验名称"/>
                        <el-table-column prop="createExperimentTime" label="评价时间">
                          <template #default="scope">
                            <span>{{scope.row.evaluateTime?scope.row.evaluateTime.substring(0,16):'--'}}</span>
                          </template>
                        </el-table-column>
                        <el-table-column prop="startTime" label="报告提交时间" show-overflow-tooltip>
                          <template #default="scope">
                            <span>{{scope.row.updateTime?scope.row.updateTime.substring(0,16):'--'}}</span>
                          </template>
                        </el-table-column>
<!--                        <el-table-column prop="experimentSite" label="实验场所" show-overflow-tooltip>-->
<!--                          <template #default="scope">-->
<!--                            <span>{{scope.row.experimentSite?.map(i=>i.siteName).join(',')}}</span>-->
<!--                          </template>-->
<!--                        </el-table-column>-->
<!--                        <el-table-column prop="experimentType" label="实验类别">-->
<!--                          <template #default="scope">-->
<!--                            <span>{{developState.experimentTypeList.find(i=>i.id == scope.row.experimentType)?.name}}</span>-->
<!--                          </template>-->
<!--                        </el-table-column>-->
                        <el-table-column label="操作" width="250" fixed="right">
                            <template #default="scope">
                                <el-button size="small" text type="primary" v-if="developState.isLeader == true && (!scope.row.person||(scope.row.person && scope.row.person.length == 0))" :icon="Edit" @click="openRiskDialog(scope.row)">审批</el-button>
                                <el-button size="small" text type="primary" :icon="Edit" @click="openReportDialog('查看',scope.row)">查看评估报告</el-button>
                            </template>
                        </el-table-column>
                    </el-table>
                    <div class="pageBtn">
                        <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="developState.searchQuery.pageIndex" background v-model:page-size="developState.searchQuery.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="developState.total" class="page-position"> </el-pagination>
                    </div>
                </div>
            </div>
        </div>
        <report-dialog ref="ReportDialogRef" @refresh="getReportData"></report-dialog>
        <el-dialog title="报告审批" v-model="developState.reviewDialogVisible" width="50%">
          <el-form ref="ruleFormRef" :rules="developState.rules" :model="developState.reviewForm" label-width="120px">
            <el-form-item label="审批结果" prop="approveStatus">
              <el-radio-group style="text-align: center" v-model="developState.reviewForm.approveStatus">
                  <el-radio :label="2">通过</el-radio>
                  <el-radio :label="3">不通过</el-radio>
              </el-radio-group>
            </el-form-item>
            <el-form-item label="主管部门意见" prop="approveDesc">
              <el-input v-model="developState.reviewForm.approveDesc" type="textarea" :autosize="{ minRows: 3 }" />
            </el-form-item>
          </el-form>
          <template #footer>
              <span class="dialog-footer" style="padding-top:10px;text-align: center !important;">
                <el-button @click="developState.reviewDialogVisible = !developState.reviewDialogVisible" size="default">取 消</el-button>
                <el-button type="primary" @click="onSubmitReview(ruleFormRef)" size="default">提交审批</el-button>
              </span>
          </template>
        </el-dialog>
    </div>
</template>

<script setup lang="ts">
import {defineAsyncComponent, onMounted, reactive, ref} from "vue";
import {projectApi} from "/@/api/experiment/project";
import {ElMessage, ElMessageBox} from "element-plus";
import type { FormInstance, FormRules } from 'element-plus'
import { View,Edit, Plus, RefreshLeft } from '@element-plus/icons-vue';
import {roomApi} from "/@/api/basic/room";
import {assessApplyApi} from "/@/api/analyse/assessApply";
import {useUserInfo} from "/@/stores/userInfo";
import {storeToRefs} from "pinia";
const userInfo = useUserInfo();
const { userInfos } = storeToRefs(userInfo);
const ReportDialog = defineAsyncComponent(() => import('./components/reportDialog.vue'));

const ReportDialogRef = ref();
const ruleFormRef = ref<FormInstance>()
const developState = reactive<reportReviewStateType>({
    developData: [],
    searchQuery: {
        pageIndex: 1,
        pageSize: 10,
        experimentName: '',
        experimentType: null,
        tag: 2
    },
    total: 0,
    experimentTypeList: [
        {id: 1, name: '化学类'},
        {id: 2, name: '生物类'},
        {id: 3, name: '辐射类'},
        {id: 4, name: '机电类'},
        {id: 5, name: '特种设备类'},
        {id: 6, name: '其它类'},
    ],
    allRoomList: [],
    reviewDialogVisible: false,
    reviewForm:{
      id: null,
      approveStatus: null,
      approveDesc: ''
    },
    isLeader: false,
    rules: {
      approveDesc: [{ required: true, message: '请输入审批意见', trigger: 'blur' }],
      approveStatus: [{ required: true, message: '请选择审批结果', trigger: 'blur' }]
    }
})

const getReportData = async () => {
    let res = await assessApplyApi().getRiskReportPage(developState.searchQuery);
    if(res.data.code === 100){
        developState.developData = res.data.data;
        console.log(developState.developData,'developState.developData')
        developState.total = res.data.total;
    }else{
        ElMessage({
            type: 'warning',
            message: res.data.msg
        });
    }
};


const getAllRoom = async () => {
  let res = await roomApi().getAllRoom();
  if(res.data.code === 100){
    developState.allRoomList = JSON.parse(JSON.stringify(res.data.data));
  }else{
    ElMessage({
      type: 'warning',
      message: res.data.msg
    })
  }
};

const openReportDialog = (title: string,value: ProjectType) =>{
  ReportDialogRef.value.showReportDialog(title, value, developState.allRoomList);
}

const onSubmitReview = async (formEl: FormInstance | undefined) => {
  if (!formEl) return
  await formEl.validate(async(valid, fields) => {
    if (valid) {
      let res = await assessApplyApi().uploadReport(developState.reviewForm);
      if(res.data.code === 100){
        ElMessage({
          type: 'success',
          message: '审批提交成功'
        });
      }else{
        ElMessage({
          type: 'warning',
          message: res.data.msg
        });
      }
      developState.reviewForm = {
        id: null,
        approveStatus: null,
        approveDesc: ''
      },
      developState.reviewDialogVisible = false
      getReportData()
    } else {
      console.log('error submit!', fields)
    }
  })
}

const openRiskDialog = (val)=>{
  developState.reviewForm.id = val.id
  developState.reviewDialogVisible = true
}

const onHandleSizeChange = (val: number) => {
    developState.searchQuery.pageSize = val;
    getReportData();
};

const onHandleCurrentChange = (val: number) => {
    developState.searchQuery.pageIndex = val;
    getReportData();
};

const reset = () => {
    developState.searchQuery = {
      pageIndex: 1,
      pageSize: 10,
      experimentName: '',
      experimentType: null,
      tag: 2
    }
};

onMounted(() => {
    getReportData()
    getAllRoom()
    console.log(userInfos.value.roles,'roles')
    if(userInfos.value.roles?.find(i=>i.roleId == '6')){
      developState.isLeader = true
    }
    console.log(developState.isManage,userInfos.value.roles)
})

</script>

<style scoped lang="scss">
$homeNavLengh: 8;
.home-container {
    height: calc(100vh - 144px);
    box-sizing: border-box;
    overflow: hidden;
    .homeCard {
        width: 100%;
        padding: 20px;
        box-sizing: border-box;
        background: #fff;
        border-radius: 4px;

        .main-card {
            width: 100%;
            height: 100%;
            .cardTop {
                display: flex;
                align-items: center;
                justify-content: space-between;
                margin-bottom: 20px;
                .mainCardBtn {
                    margin: 0;
                }
            }
            .pageBtn {
                height: 60px;
                display: flex;
                align-items: center;
                justify-content: right;

                .demo-pagination-block + .demo-pagination-block {
                    margin-top: 10px;
                }
                .demo-pagination-block .demonstration {
                    margin-bottom: 16px;
                }
            }
        }
        &:last-of-type {
            height: calc(100% - 100px);
        }
    }
    .el-row {
        display: flex;
        align-items: center;
        margin-bottom: 20px;
        &:last-child {
            margin-bottom: 0;
        }
        .grid-content {
            align-items: center;
            min-height: 36px;
        }

        .topInfo {
            display: flex;
            align-items: center;
            font-size: 16px;
            font-weight: bold;

            & > div {
                white-space: nowrap;
                margin-right: 20px;
            }
        }
    }
}
.stepItem {
    width: 100%;
    display: flex;
    align-items: flex-start;
    margin-bottom: 30px;
    margin-left: 30px;
    padding-bottom: 30px;
    border-left: 2px solid #ccc;
    &:first-of-type {
        margin-top: 30px;
    }
    &:last-of-type {
        margin-bottom: 0;
        border-left: none;
    }
    .stepNum {
        width: 30px;
        height: 30px;
        border-radius: 15px;
        box-sizing: border-box;
        color: #333;
        border: 1px solid #999;
        line-height: 28px;
        text-align: center;
        margin-right: 10px;
        margin-left: -16px;
        margin-top: -30px;
    }
    .stepCard {
        width: 100%;
        margin-top: -30px;

        .box-card {
            width: 100%;
            &:deep(.el-card__header) {
                padding: 10px 15px;
            }
            .card-header {
                width: 100%;
                display: flex;
                justify-content: space-between;
                align-items: center;
                & > div:first-of-type {
                    margin-right: 80px;
                    font-size: 18px;
                    font-weight: bold;
                }
            }
        }
    }
    &:hover .card-header {
        color: #0098f5;
    }
    &:hover .stepNum {
        border: 2px solid #0098f5;
        color: #0098f5;
    }
}

:deep(.el-date-editor) {
    width: 100%;
}
.el-select {
    width: 100%;
}
:deep(.el-textarea.is-disabled .el-textarea__inner) {
    background-color: var(--el-card-bg-color);
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__inner) {
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__wrapper) {
    background-color: var(--el-card-bg-color);
    box-shadow: none;
}
</style>
